@@ -77,15 +77,15 @@ class InstanceContainer(QObject, ContainerInterface, PluginObject):
 
     def __deepcopy__(self, memo: Dict[int, object]) -> "InstanceContainer":
         new_container = self.__class__(self.getId())
-        new_container._metadata = copy.deepcopy(self._metadata, memo)
+        new_container._metadata = cast(Dict[str, Any], copy.deepcopy(self._metadata, memo))
         new_container._instances = cast(Dict[str, SettingInstance], copy.deepcopy(self._instances, memo))
         for instance in new_container._instances.values(): #Set the back-links of the new instances correctly to the copied container.
             instance._container = new_container
             instance.propertyChanged.connect(new_container.propertyChanged)
         new_container._read_only = self._read_only
         new_container._dirty = self._dirty
-        new_container._path = copy.deepcopy(self._path, memo)
-        new_container._cached_values = copy.deepcopy(self._cached_values, memo)
+        new_container._path = cast(str, copy.deepcopy(self._path, memo))
+        new_container._cached_values = cast(Optional[Dict[str, Any]], copy.deepcopy(self._cached_values, memo))
         return new_container
 
     def __eq__(self, other: object) -> bool:
@@ -194,6 +194,9 @@ class InstanceContainer(QObject, ContainerInterface, PluginObject):
         return _containerRegistry.isReadOnly(self.getId())
     readOnly = pyqtProperty(bool, fget = getReadOnly)
 
+    def getNumInstances(self) -> int:
+        return len(self._instances)
+
     ##  \copydoc ContainerInterface::getMetaData
     #
     #   Reimplemented from ContainerInterface
@@ -436,8 +439,8 @@ class InstanceContainer(QObject, ContainerInterface, PluginObject):
         parser.read_string(serialized)
 
         has_general = "general" in parser
-        has_version = "version" in parser["general"]
-        has_definition = "definition" in parser["general"]
+        has_version = has_general and "version" in parser["general"]
+        has_definition = has_general and "definition" in parser["general"]
 
         if not has_general or not has_version or not has_definition:
             exception_string = "Missing the required"
@@ -552,9 +555,9 @@ class InstanceContainer(QObject, ContainerInterface, PluginObject):
     def _instantiateCachedValues(self) -> None:
         if not self._cached_values:
             return
-
+        definition = self.getDefinition()
         for key, value in self._cached_values.items():
-            self.setProperty(key, "value", value, self.getDefinition(), set_from_cache=True)
+            self.setProperty(key, "value", value, definition, set_from_cache=True)
 
         self._cached_values = None
 
